@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Registry object
 ##
-## Copyright (c) 2005,2006,2007,2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005-2010 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -32,7 +32,7 @@ use Net::DRI::Data::RegistryObject;
 
 our $AUTOLOAD;
 
-our $VERSION=do { my @r=(q$Revision: 1.31 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.32 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -62,7 +62,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2006,2007,2008,2009 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005-2010 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -425,9 +425,8 @@ sub end
  {
   my $p=$self->{profiles}->{$name};
   $p->{protocol}->end()  if (ref($p->{protocol})  && $p->{protocol}->can('end'));
-  $p->{transport}->end({registry => $self, profile => $name}) if (ref($p->{transport}) && $p->{transport}->can('end'));
-  ## extra ?
-  $p={};
+  $p->{transport}->end() if (ref($p->{transport}) && $p->{transport}->can('end'));
+  delete $self->{profiles}->{$name}
  }
 
  $self->{driver}->end() if $self->{driver}->can('end');
@@ -462,7 +461,7 @@ sub process
  ## Current protocol/transport objects for current profile
  my ($po,$to)=$self->protocol_transport();
  my $trid=$self->generate_trid();
- my $ctx={trid => $trid, registry => $self, profile => $self->profile(), otype => $otype, oaction => $oaction };
+ my $ctx={trid => $trid, otype => $otype, oaction => $oaction, phase => 'active' };
  my $tosend;
 
  eval { $tosend=$po->action($otype,$oaction,$trid,@$pa); }; ## TODO : this may need to be pushed in loop below if we need to change message to send when failure
@@ -531,7 +530,7 @@ sub format_error
 sub process_back
 {
  my ($self,$trid,$po,$to,$otype,$oaction,$count)=@_;
- my $ctx={trid => $trid, registry => $self, profile => $self->profile(), otype => $otype, oaction => $oaction }; ## How will we fill that in case of async operation (direct call here) ?
+ my $ctx={trid => $trid, otype => $otype, oaction => $oaction }; ## How will we fill that in case of async operation (direct call here) ?
  my ($rc,$ri,$oname);
 
  $self->log_output('debug','core','Attempting to receive data from registry for TRID='.$trid);
